pub struct ClassSubtable<'a> {
data: FontData<'a>,
}Expand description
Maps the glyph indexes of your font into classes.
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> ClassSubtable<'a>
impl<'a> ClassSubtable<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn first_glyph(&self) -> u16
pub fn first_glyph(&self) -> u16
Glyph index of the first glyph in the class table.
Sourcepub fn class_array(&self) -> &'a [u8] ⓘ
pub fn class_array(&self) -> &'a [u8] ⓘ
The class codes (indexed by glyph index minus firstGlyph). Class codes range from 0 to the value of stateSize minus 1.
pub fn first_glyph_byte_range(&self) -> Range<usize> ⓘ
pub fn n_glyphs_byte_range(&self) -> Range<usize> ⓘ
pub fn class_array_byte_range(&self) -> Range<usize> ⓘ