pub struct Lookup10<'a> {
data: FontData<'a>,
}Expand description
Trimmed array format. The lookup data is a simple trimmed array indexed by glyph index.
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> Lookup10<'a>
impl<'a> Lookup10<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn unit_size(&self) -> u16
pub fn unit_size(&self) -> u16
Size of a lookup unit for this lookup table in bytes. Allowed values are 1, 2, 4, and 8.
Sourcepub fn first_glyph(&self) -> u16
pub fn first_glyph(&self) -> u16
First glyph index included in the trimmed array.
Sourcepub fn glyph_count(&self) -> u16
pub fn glyph_count(&self) -> u16
Total number of glyphs (equivalent to the last glyph minus the value of firstGlyph plus 1).
Sourcepub fn values_data(&self) -> &'a [u8] ⓘ
pub fn values_data(&self) -> &'a [u8] ⓘ
The lookup values (indexed by the glyph index minus the value of firstGlyph).