Lookup8

Struct Lookup8 

pub struct Lookup8<'a> {
    data: FontData<'a>,
}
Trimmed array format. The lookup data is a simple trimmed array indexed by glyph index.

Fields

data: FontData<'a>

Implementations

Source

impl<'a> Lookup8<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn format(&self) -> u16

Format number is set to 8.

pub fn first_glyph(&self) -> u16

First glyph index included in the trimmed array.

pub fn glyph_count(&self) -> u16

Total number of glyphs (equivalent to the last glyph minus the value of firstGlyph plus 1).

pub fn value_array(&self) -> &'a [BigEndian<u16>]

The lookup values (indexed by the glyph index minus the value of firstGlyph). Entries in the value array must be two bytes.

pub fn format_byte_range(&self) -> Range<usize>

pub fn first_glyph_byte_range(&self) -> Range<usize>

pub fn glyph_count_byte_range(&self) -> Range<usize>

pub fn value_array_byte_range(&self) -> Range<usize>

Source

impl Lookup8<'_>

pub fn value<T: LookupValue>(&self, index: u16) -> Result<T, ReadError>