pub struct StxHeader<'a> {
data: FontData<'a>,
}Expand description
Header for an extended state table.
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> StxHeader<'a>
impl<'a> StxHeader<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn n_classes(&self) -> u32
pub fn n_classes(&self) -> u32
Number of classes, which is the number of 16-bit entry indices in a single line in the state array.
Sourcepub fn class_table_offset(&self) -> Offset32
pub fn class_table_offset(&self) -> Offset32
Byte offset from the beginning of the state table to the class subtable.
Sourcepub fn class_table(&self) -> Result<LookupU16<'a>, ReadError>
pub fn class_table(&self) -> Result<LookupU16<'a>, ReadError>
Attempt to resolve class_table_offset.
Sourcepub fn state_array_offset(&self) -> Offset32
pub fn state_array_offset(&self) -> Offset32
Byte offset from the beginning of the state table to the state array.
Sourcepub fn state_array(&self) -> Result<RawWords<'a>, ReadError>
pub fn state_array(&self) -> Result<RawWords<'a>, ReadError>
Attempt to resolve state_array_offset.
Sourcepub fn entry_table_offset(&self) -> Offset32
pub fn entry_table_offset(&self) -> Offset32
Byte offset from the beginning of the state table to the entry subtable.
Sourcepub fn entry_table(&self) -> Result<RawBytes<'a>, ReadError>
pub fn entry_table(&self) -> Result<RawBytes<'a>, ReadError>
Attempt to resolve entry_table_offset.